@@ -75,7 +75,8 @@ LISTENER_ROWS = (
     'client_ca_tls_container_ref',
     'client_authentication',
     'client_crl_container_ref',
-    'allowed_cidrs')
+    'allowed_cidrs',
+    'tls_ciphers')
 
 LISTENER_COLUMNS = (
     'id',
@@ -106,7 +107,8 @@ POOL_ROWS = (
     'tls_container_ref',
     'ca_tls_container_ref',
     'crl_container_ref',
-    'tls_enabled')
+    'tls_enabled',
+    'tls_ciphers')
 
 POOL_COLUMNS = (
     'id',
@@ -277,6 +279,18 @@ AMPHORA_COLUMNS = (
     'ha_ip',
 )
 
+AMPHORA_COLUMNS_LONG = (
+    'id',
+    'loadbalancer_id',
+    'status',
+    'role',
+    'lb_network_ip',
+    'ha_ip',
+    'compute_id',
+    'cached_zone',
+    'image_id',
+)
+
 PROVIDER_COLUMNS = (
     'name',
     'description',
@@ -343,3 +357,11 @@ AVAILABILITYZONEPROFILE_COLUMNS = (
 )
 
 PROVISIONING_STATUS = 'provisioning_status'
+
+# TCP/UDP port min/max
+MIN_PORT_NUMBER = 1
+MAX_PORT_NUMBER = 65535
+
+# Member weight min/max
+MIN_WEIGHT = 0
+MAX_WEIGHT = 256
