@@ -382,7 +382,7 @@ class UnsetL7Policy(command.Command):
 
     def take_action(self, parsed_args):
         unset_args = v2_utils.get_unsets(parsed_args)
-        if not len(unset_args):
+        if not unset_args:
             return
 
         policy_id = v2_utils.get_resource_id(
