@@ -12,9 +12,8 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-
 import copy
-import mock
+from unittest import mock
 
 from osc_lib import exceptions
 
@@ -206,7 +205,7 @@ class TestFlavorUnset(TestFlavor):
             arg_param = (ref_param.replace('_', '-') if '_' in ref_param else
                          ref_param)
             arglist.append('--%s' % arg_param)
-        verifylist = list(zip(self.PARAMETERS, [True]*len(self.PARAMETERS)))
+        verifylist = list(zip(self.PARAMETERS, [True] * len(self.PARAMETERS)))
         verifylist = [('flavor', self._flavor.id)] + verifylist
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
@@ -216,7 +215,7 @@ class TestFlavorUnset(TestFlavor):
     def test_flavor_unset_none(self):
         self.api_mock.flavor_set.reset_mock()
         arglist = [self._flavor.id]
-        verifylist = list(zip(self.PARAMETERS, [False]*len(self.PARAMETERS)))
+        verifylist = list(zip(self.PARAMETERS, [False] * len(self.PARAMETERS)))
         verifylist = [('flavor', self._flavor.id)] + verifylist
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
