@@ -12,9 +12,8 @@
 #   License for the specific language governing permissions and limitations
 #   under the License.
 #
-
 import copy
-import mock
+from unittest import mock
 
 from osc_lib import exceptions
 
@@ -336,7 +335,7 @@ class TestHealthMonitorUnset(TestHealthMonitor):
             arg_param = (ref_param.replace('_', '-') if '_' in ref_param else
                          ref_param)
             arglist.append('--%s' % arg_param)
-        verifylist = list(zip(self.PARAMETERS, [True]*len(self.PARAMETERS)))
+        verifylist = list(zip(self.PARAMETERS, [True] * len(self.PARAMETERS)))
         verifylist = [('health_monitor', self._hm.id)] + verifylist
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
@@ -346,7 +345,7 @@ class TestHealthMonitorUnset(TestHealthMonitor):
     def test_hm_unset_none(self):
         self.api_mock.health_monitor_set.reset_mock()
         arglist = [self._hm.id]
-        verifylist = list(zip(self.PARAMETERS, [False]*len(self.PARAMETERS)))
+        verifylist = list(zip(self.PARAMETERS, [False] * len(self.PARAMETERS)))
         verifylist = [('health_monitor', self._hm.id)] + verifylist
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
