@@ -12,9 +12,8 @@
 #   License for the specific language governing permissions and limitations
 #   under the License.
 #
-
 import copy
-import mock
+from unittest import mock
 
 from octaviaclient.osc.v2 import constants
 from octaviaclient.osc.v2 import l7rule
@@ -365,7 +364,7 @@ class TestL7RuleUnset(TestL7Rule):
             arg_param = (ref_param.replace('_', '-') if '_' in ref_param else
                          ref_param)
             arglist.append('--%s' % arg_param)
-        verifylist = list(zip(self.PARAMETERS, [True]*len(self.PARAMETERS)))
+        verifylist = list(zip(self.PARAMETERS, [True] * len(self.PARAMETERS)))
         verifylist = [('l7rule_id', self._l7ru.id)] + verifylist
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
@@ -375,7 +374,7 @@ class TestL7RuleUnset(TestL7Rule):
     def test_l7rule_unset_none(self):
         self.api_mock.l7rule_set.reset_mock()
         arglist = [self._l7po.id, self._l7ru.id]
-        verifylist = list(zip(self.PARAMETERS, [False]*len(self.PARAMETERS)))
+        verifylist = list(zip(self.PARAMETERS, [False] * len(self.PARAMETERS)))
         verifylist = [('l7rule_id', self._l7ru.id)] + verifylist
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
