@@ -10,9 +10,8 @@
 #   License for the specific language governing permissions and limitations
 #   under the License.
 #
-
 import copy
-import mock
+from unittest import mock
 
 from osc_lib import exceptions
 
@@ -250,7 +249,7 @@ class TestQuotaUnset(TestQuota):
             arg_param = (ref_param.replace('_', '-') if '_' in ref_param else
                          ref_param)
             arglist.append('--%s' % arg_param)
-        verifylist = list(zip(self.PARAMETERS, [True]*len(self.PARAMETERS)))
+        verifylist = list(zip(self.PARAMETERS, [True] * len(self.PARAMETERS)))
         verifylist = [('project', self._qt.project_id)] + verifylist
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
@@ -260,7 +259,7 @@ class TestQuotaUnset(TestQuota):
     def test_quota_unset_none(self):
         self.api_mock.quota_set.reset_mock()
         arglist = [self._qt.project_id]
-        verifylist = list(zip(self.PARAMETERS, [False]*len(self.PARAMETERS)))
+        verifylist = list(zip(self.PARAMETERS, [False] * len(self.PARAMETERS)))
         verifylist = [('project', self._qt.project_id)] + verifylist
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
